ShuffleProof

Type Alias ShuffleProof 

pub type ShuffleProof = PlonkProof<KZGCommitmentSchemeBN254>;

Aliased Type

pub struct ShuffleProof {
Show 14 fields pub cm_w_vec: Vec<KZGCommitment<Projective<Config>>>, pub cm_w_sel_vec: Vec<KZGCommitment<Projective<Config>>>, pub cm_t_vec: Vec<KZGCommitment<Projective<Config>>>, pub cm_z: KZGCommitment<Projective<Config>>, pub prk_3_poly_eval_zeta: Fp<MontBackend<FrConfig, 4>, 4>, pub prk_4_poly_eval_zeta: Fp<MontBackend<FrConfig, 4>, 4>, pub w_polys_eval_zeta: Vec<Fp<MontBackend<FrConfig, 4>, 4>>, pub w_polys_eval_zeta_omega: Vec<Fp<MontBackend<FrConfig, 4>, 4>>, pub z_eval_zeta_omega: Fp<MontBackend<FrConfig, 4>, 4>, pub s_polys_eval_zeta: Vec<Fp<MontBackend<FrConfig, 4>, 4>>, pub q_ecc_poly_eval_zeta: Fp<MontBackend<FrConfig, 4>, 4>, pub w_sel_polys_eval_zeta: Vec<Fp<MontBackend<FrConfig, 4>, 4>>, pub opening_witness_zeta: KZGCommitment<Projective<Config>>, pub opening_witness_zeta_omega: KZGCommitment<Projective<Config>>,
}

Fields

cm_w_vec: Vec<KZGCommitment<Projective<Config>>>

The witness polynomial commitments.

cm_w_sel_vec: Vec<KZGCommitment<Projective<Config>>>

The witness selector polynomial commitments.

cm_t_vec: Vec<KZGCommitment<Projective<Config>>>

The split quotient polynomial commitments

cm_z: KZGCommitment<Projective<Config>>

The sigma polynomial commitment.

prk_3_poly_eval_zeta: Fp<MontBackend<FrConfig, 4>, 4>

The opening of the third preprocessed round key polynomial at \zeta.

prk_4_poly_eval_zeta: Fp<MontBackend<FrConfig, 4>, 4>

The opening of the fourth preprocessed round key polynomial at \zeta.

w_polys_eval_zeta: Vec<Fp<MontBackend<FrConfig, 4>, 4>>

The openings of witness polynomials at \zeta.

w_polys_eval_zeta_omega: Vec<Fp<MontBackend<FrConfig, 4>, 4>>

The openings of witness polynomials (first three) at \zeta * \omega.

z_eval_zeta_omega: Fp<MontBackend<FrConfig, 4>, 4>

The opening of z(X) at point \zeta * \omega.

s_polys_eval_zeta: Vec<Fp<MontBackend<FrConfig, 4>, 4>>

The openings of permutation polynomials at \zeta.

q_ecc_poly_eval_zeta: Fp<MontBackend<FrConfig, 4>, 4>

The opening of q_{ecc}(X) at point \zeta .

w_sel_polys_eval_zeta: Vec<Fp<MontBackend<FrConfig, 4>, 4>>

The opening of the witness selector polynomial at point \zeta .

opening_witness_zeta: KZGCommitment<Projective<Config>>

The commitment for the first witness polynomial, for \zeta.

opening_witness_zeta_omega: KZGCommitment<Projective<Config>>

The commitment for the second witness polynomial, for \zeta\omega.